CodeMirror: Bi-directional Text Demo

## Bi-directional Text Demo

<!-- Piece of the CodeMirror manual, 'translated' into Arabic by Google Translate --> <dl> <dt id=option_value><code>value (string or Doc)</code></dt> <dd>قيمة البداية المحرر. يمكن أن تكون سلسلة، أو. كائن مستند.</dd> <dt id=option_mode><code>mode (string or object)</code></dt> <dd>وضع الاستخدام. عندما لا تعطى، وهذا الافتراضي إلى الطريقة الاولى التي تم تحميلها. قد يكون من سلسلة، والتي إما أسماء أو ببساطة هو وضع MIME نوع المرتبطة اسطة. بدلا من ذلك، قد يكون من كائن يحتوي على خيارات التكوين لواسطة، مع <code>name</code> الخاصية التي وضع أسماء (على سبيل المثال <code>{name: "javascript", json: true}</code>). صفحات التجريبي لكل وضع تحتوي على معلومات حول ما معلمات تكوين وضع يدعمها. يمكنك أن تطلب CodeMirror التي تم تعريفها طرق وأنواع MIME الكشف على <code>CodeMirror.modes</code> و <code>CodeMirror.mimeModes</code> الكائنات. وضع خرائط الأسماء الأولى لمنشئات الخاصة بهم، وخرائط لأنواع MIME 2 المواصفات واسطة.</dd> <dt id=option_theme><code>theme (string)</code></dt> <dd>موضوع لنمط المحرر مع. يجب عليك التأكد من الملف CSS تحديد المقابلة <code>.cm-s-[name]</code> يتم تحميل أنماط (انظر <a href="../theme/"><code>theme</code></a> الدليل في التوزيع). الافتراضي هو <code>"default"</code> ، والتي تم تضمينها في الألوان <code>codemirror.css</code>. فمن الممكن استخدام فئات متعددة في تطبيق السمات مرة واحدة على سبيل المثال <code>"foo bar"</code> سيتم تعيين كل من <code>cm-s-foo</code> و <code>cm-s-bar</code> الطبقات إلى المحرر.</dd> </dl>

Demonstration of bi-directional text support. See the related blog post for more background.

Note: There is a known bug with cursor motion and mouse clicks in bi-directional lines that are line wrapped.